==> pyemr-0.1.0.tar.gz: pyemr-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyemr', 'pyemr.pyemr', 'pyemr.pyemr.utils', 'pyemr.utils']

package_data = \
{'': ['*'],
 'pyemr': ['.git/*',
           '.git/hooks/*',
           '.git/info/*',
           '.git/logs/*',
           '.git/logs/refs/heads/*',
           '.git/logs/refs/remotes/origin/*',
           '.git/objects/00/*',
           '.git/objects/01/*',
           '.git/objects/02/*',
           '.git/objects/03/*',
           '.git/objects/06/*',
           '.git/objects/07/*',
           '.git/objects/09/*',
           '.git/objects/0d/*',
           '.git/objects/0e/*',
           '.git/objects/0f/*',
           '.git/objects/11/*',
           '.git/objects/12/*',
           '.git/objects/17/*',
           '.git/objects/1a/*',
           '.git/objects/1c/*',
           '.git/objects/1d/*',
           '.git/objects/20/*',
           '.git/objects/21/*',
           '.git/objects/23/*',
           '.git/objects/24/*',
           '.git/objects/25/*',
           '.git/objects/26/*',
           '.git/objects/27/*',
           '.git/objects/28/*',
           '.git/objects/29/*',
           '.git/objects/2a/*',
           '.git/objects/2b/*',
           '.git/objects/2c/*',
           '.git/objects/2d/*',
           '.git/objects/31/*',
           '.git/objects/33/*',
           '.git/objects/35/*',
           '.git/objects/36/*',
           '.git/objects/38/*',
           '.git/objects/3d/*',
           '.git/objects/3f/*',
           '.git/objects/40/*',
           '.git/objects/41/*',
           '.git/objects/42/*',
           '.git/objects/44/*',
           '.git/objects/46/*',
           '.git/objects/47/*',
           '.git/objects/48/*',
           '.git/objects/4b/*',
           '.git/objects/4c/*',
           '.git/objects/4d/*',
           '.git/objects/4e/*',
           '.git/objects/4f/*',
           '.git/objects/50/*',
           '.git/objects/52/*',
           '.git/objects/54/*',
           '.git/objects/57/*',
           '.git/objects/58/*',
           '.git/objects/59/*',
           '.git/objects/5b/*',
           '.git/objects/5c/*',
           '.git/objects/5e/*',
           '.git/objects/61/*',
           '.git/objects/63/*',
           '.git/objects/64/*',
           '.git/objects/67/*',
           '.git/objects/68/*',
           '.git/objects/69/*',
           '.git/objects/6a/*',
           '.git/objects/6b/*',
           '.git/objects/6d/*',
           '.git/objects/70/*',
           '.git/objects/73/*',
           '.git/objects/75/*',
           '.git/objects/77/*',
           '.git/objects/78/*',
           '.git/objects/7a/*',
           '.git/objects/7d/*',
           '.git/objects/80/*',
           '.git/objects/81/*',
           '.git/objects/85/*',
           '.git/objects/86/*',
           '.git/objects/88/*',
           '.git/objects/89/*',
           '.git/objects/8a/*',
           '.git/objects/8b/*',
           '.git/objects/8d/*',
           '.git/objects/91/*',
           '.git/objects/93/*',
           '.git/objects/95/*',
           '.git/objects/96/*',
           '.git/objects/97/*',
           '.git/objects/98/*',
           '.git/objects/99/*',
           '.git/objects/9b/*',
           '.git/objects/9d/*',
           '.git/objects/9e/*',
           '.git/objects/a0/*',
           '.git/objects/a1/*',
           '.git/objects/a2/*',
           '.git/objects/a4/*',
           '.git/objects/a5/*',
           '.git/objects/a6/*',
           '.git/objects/a7/*',
           '.git/objects/a8/*',
           '.git/objects/a9/*',
           '.git/objects/aa/*',
           '.git/objects/ab/*',
           '.git/objects/ac/*',
           '.git/objects/ad/*',
           '.git/objects/af/*',
           '.git/objects/b0/*',
           '.git/objects/b3/*',
           '.git/objects/b6/*',
           '.git/objects/ba/*',
           '.git/objects/bc/*',
           '.git/objects/bd/*',
           '.git/objects/be/*',
           '.git/objects/bf/*',
           '.git/objects/c1/*',
           '.git/objects/c2/*',
           '.git/objects/c4/*',
           '.git/objects/c5/*',
           '.git/objects/c6/*',
           '.git/objects/c7/*',
           '.git/objects/c9/*',
           '.git/objects/ca/*',
           '.git/objects/ce/*',
           '.git/objects/d0/*',
           '.git/objects/d1/*',
           '.git/objects/d2/*',
           '.git/objects/d3/*',
           '.git/objects/d6/*',
           '.git/objects/d7/*',
           '.git/objects/d8/*',
           '.git/objects/d9/*',
           '.git/objects/da/*',
           '.git/objects/db/*',
           '.git/objects/dc/*',
           '.git/objects/df/*',
           '.git/objects/e0/*',
           '.git/objects/e3/*',
           '.git/objects/e6/*',
           '.git/objects/e7/*',
           '.git/objects/e9/*',
           '.git/objects/eb/*',
           '.git/objects/ed/*',
           '.git/objects/ee/*',
           '.git/objects/f0/*',
           '.git/objects/f1/*',
           '.git/objects/f2/*',
           '.git/objects/f4/*',
           '.git/objects/f6/*',
           '.git/objects/f8/*',
           '.git/objects/f9/*',
           '.git/objects/fa/*',
           '.git/objects/fc/*',
           '.git/objects/fd/*',
           '.git/objects/fe/*',
           '.git/refs/heads/*',
           '.git/refs/remotes/origin/*',
           '.media/*'],
 'pyemr.pyemr': ['docker/*']}

install_requires = \
['awswrangler>=2.13.0,<3.0.0',
 'boto3>=1.20.23,<2.0.0',
 'fire>=0.4.0,<0.5.0',
 'loguru>=0.5.3,<0.6.0',
 'pandas>=1.3.5,<2.0.0',
 'poetry>=1.1.12,<2.0.0',
 'sh>=1.14.2,<2.0.0',
 'tomlkit==0.7.2',
 'tqdm>=4.62.3,<5.0.0']

entry_points = \
{'console_scripts': ['pyemr = pyemr.cli:main']}

setup_kwargs = {
    'name': 'pyemr',
    'version': '0.1.0',
    'description': 'A lightweight package for running poetry projects on emr.',
    'long_description': None,
    'author': 'Richard Brooker',
    'author_email': 'richjbrooker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.1,<3.10',
}


setup(**setup_kwargs)

==> pyemr-0.1.4.tar.gz: pyemr-0.1.4/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyemr', 'pyemr.pyemr', 'pyemr.pyemr.utils', 'pyemr.utils']

package_data = \
{'': ['*'],
 'pyemr': ['.git/*',
           '.git/hooks/*',
           '.git/info/*',
           '.git/logs/*',
           '.git/logs/refs/heads/*',
           '.git/logs/refs/remotes/origin/*',
           '.git/objects/00/*',
           '.git/objects/01/*',
           '.git/objects/02/*',
           '.git/objects/03/*',
           '.git/objects/06/*',
           '.git/objects/07/*',
           '.git/objects/08/*',
           '.git/objects/09/*',
           '.git/objects/0d/*',
           '.git/objects/0e/*',
           '.git/objects/0f/*',
           '.git/objects/11/*',
           '.git/objects/12/*',
           '.git/objects/15/*',
           '.git/objects/17/*',
           '.git/objects/1a/*',
           '.git/objects/1c/*',
           '.git/objects/1d/*',
           '.git/objects/1f/*',
           '.git/objects/20/*',
           '.git/objects/21/*',
           '.git/objects/23/*',
           '.git/objects/24/*',
           '.git/objects/25/*',
           '.git/objects/26/*',
           '.git/objects/27/*',
           '.git/objects/28/*',
           '.git/objects/29/*',
           '.git/objects/2a/*',
           '.git/objects/2b/*',
           '.git/objects/2c/*',
           '.git/objects/2d/*',
           '.git/objects/30/*',
           '.git/objects/31/*',
           '.git/objects/33/*',
           '.git/objects/35/*',
           '.git/objects/36/*',
           '.git/objects/38/*',
           '.git/objects/3b/*',
           '.git/objects/3d/*',
           '.git/objects/3e/*',
           '.git/objects/3f/*',
           '.git/objects/40/*',
           '.git/objects/41/*',
           '.git/objects/42/*',
           '.git/objects/44/*',
           '.git/objects/46/*',
           '.git/objects/47/*',
           '.git/objects/48/*',
           '.git/objects/4b/*',
           '.git/objects/4c/*',
           '.git/objects/4d/*',
           '.git/objects/4e/*',
           '.git/objects/4f/*',
           '.git/objects/50/*',
           '.git/objects/51/*',
           '.git/objects/52/*',
           '.git/objects/54/*',
           '.git/objects/56/*',
           '.git/objects/57/*',
           '.git/objects/58/*',
           '.git/objects/59/*',
           '.git/objects/5b/*',
           '.git/objects/5c/*',
           '.git/objects/5e/*',
           '.git/objects/5f/*',
           '.git/objects/61/*',
           '.git/objects/62/*',
           '.git/objects/63/*',
           '.git/objects/64/*',
           '.git/objects/67/*',
           '.git/objects/68/*',
           '.git/objects/69/*',
           '.git/objects/6a/*',
           '.git/objects/6b/*',
           '.git/objects/6d/*',
           '.git/objects/6e/*',
           '.git/objects/70/*',
           '.git/objects/71/*',
           '.git/objects/72/*',
           '.git/objects/73/*',
           '.git/objects/75/*',
           '.git/objects/77/*',
           '.git/objects/78/*',
           '.git/objects/7a/*',
           '.git/objects/7d/*',
           '.git/objects/80/*',
           '.git/objects/81/*',
           '.git/objects/82/*',
           '.git/objects/84/*',
           '.git/objects/85/*',
           '.git/objects/86/*',
           '.git/objects/88/*',
           '.git/objects/89/*',
           '.git/objects/8a/*',
           '.git/objects/8b/*',
           '.git/objects/8c/*',
           '.git/objects/8d/*',
           '.git/objects/8f/*',
           '.git/objects/90/*',
           '.git/objects/91/*',
           '.git/objects/93/*',
           '.git/objects/95/*',
           '.git/objects/96/*',
           '.git/objects/97/*',
           '.git/objects/98/*',
           '.git/objects/99/*',
           '.git/objects/9b/*',
           '.git/objects/9d/*',
           '.git/objects/9e/*',
           '.git/objects/a0/*',
           '.git/objects/a1/*',
           '.git/objects/a2/*',
           '.git/objects/a4/*',
           '.git/objects/a5/*',
           '.git/objects/a6/*',
           '.git/objects/a7/*',
           '.git/objects/a8/*',
           '.git/objects/a9/*',
           '.git/objects/aa/*',
           '.git/objects/ab/*',
           '.git/objects/ac/*',
           '.git/objects/ad/*',
           '.git/objects/af/*',
           '.git/objects/b0/*',
           '.git/objects/b1/*',
           '.git/objects/b3/*',
           '.git/objects/b5/*',
           '.git/objects/b6/*',
           '.git/objects/b8/*',
           '.git/objects/ba/*',
           '.git/objects/bc/*',
           '.git/objects/bd/*',
           '.git/objects/be/*',
           '.git/objects/bf/*',
           '.git/objects/c0/*',
           '.git/objects/c1/*',
           '.git/objects/c2/*',
           '.git/objects/c3/*',
           '.git/objects/c4/*',
           '.git/objects/c5/*',
           '.git/objects/c6/*',
           '.git/objects/c7/*',
           '.git/objects/c9/*',
           '.git/objects/ca/*',
           '.git/objects/cb/*',
           '.git/objects/cc/*',
           '.git/objects/cd/*',
           '.git/objects/ce/*',
           '.git/objects/cf/*',
           '.git/objects/d0/*',
           '.git/objects/d1/*',
           '.git/objects/d2/*',
           '.git/objects/d3/*',
           '.git/objects/d4/*',
           '.git/objects/d6/*',
           '.git/objects/d7/*',
           '.git/objects/d8/*',
           '.git/objects/d9/*',
           '.git/objects/da/*',
           '.git/objects/db/*',
           '.git/objects/dc/*',
           '.git/objects/de/*',
           '.git/objects/df/*',
           '.git/objects/e0/*',
           '.git/objects/e1/*',
           '.git/objects/e3/*',
           '.git/objects/e4/*',
           '.git/objects/e6/*',
           '.git/objects/e7/*',
           '.git/objects/e9/*',
           '.git/objects/eb/*',
           '.git/objects/ec/*',
           '.git/objects/ed/*',
           '.git/objects/ee/*',
           '.git/objects/f0/*',
           '.git/objects/f1/*',
           '.git/objects/f2/*',
           '.git/objects/f4/*',
           '.git/objects/f6/*',
           '.git/objects/f7/*',
           '.git/objects/f8/*',
           '.git/objects/f9/*',
           '.git/objects/fa/*',
           '.git/objects/fc/*',
           '.git/objects/fd/*',
           '.git/objects/fe/*',
           '.git/refs/heads/*',
           '.git/refs/remotes/origin/*',
           '.media/*'],
 'pyemr.pyemr': ['docker/*']}

install_requires = \
['awswrangler>=2.13.0,<3.0.0',
 'boto3>=1.20.23,<2.0.0',
 'fire>=0.4.0,<0.5.0',
 'loguru>=0.5.3,<0.6.0',
 'pandas>=1.3.5,<2.0.0',
 'poetry>=1.1.12,<2.0.0',
 'sh>=1.14.2,<2.0.0',
 'tomlkit==0.7.2',
 'tqdm>=4.62.3,<5.0.0']

entry_points = \
{'console_scripts': ['pyemr = pyemr.cli:main']}

setup_kwargs = {
    'name': 'pyemr',
    'version': '0.1.4',
    'description': 'A lightweight package for running poetry projects on emr.',
    'long_description': None,
    'author': 'Richard Brooker',
    'author_email': 'richjbrooker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.1,<3.10',
}


setup(**setup_kwargs)
